@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2017 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -15,7 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Datamash.  If not, see <http://www.gnu.org/licenses/>.
+   along with GNU Datamash.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 /* Written by Assaf Gordon */
@@ -153,6 +153,8 @@ struct operation_data operations[] =
   {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_FRACTION */
   {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
+  /* OP_TRIMMED_MEAN */
+  {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
   {0, 0, NUMERIC_RESULT}
 };
 
@@ -506,6 +508,7 @@ field_op_collect (struct fieldop *op,
     case OP_S_COVARIANCE:
     case OP_P_PEARSON_COR:
     case OP_S_PEARSON_COR:
+    case OP_TRIMMED_MEAN:
       field_op_add_value (op, num_value);
       break;
 
@@ -692,6 +695,7 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_TRUNCATE:
     case OP_FRACTION:
     case OP_RANGE:
+    case OP_TRIMMED_MEAN:
       numeric_result = nanl ("");
       break;
 
@@ -738,9 +742,9 @@ field_op_summarize_empty (struct fieldop *op)
 
   if (op->res_type==NUMERIC_RESULT)
     {
-      field_op_reserve_out_buf (op, numeric_output_precision*2);
+      field_op_reserve_out_buf (op, numeric_output_bufsize);
       snprintf (op->out_buf, op->out_buf_alloc,
-                "%.*Lg", numeric_output_precision, numeric_result);
+                numeric_output_format, numeric_result);
     }
 }
 
@@ -822,6 +826,12 @@ field_op_summarize (struct fieldop *op)
                                           op->params.percentile / 100.0 );
       break;
 
+    case OP_TRIMMED_MEAN:
+      field_op_sort_values (op);
+      numeric_result = trimmed_mean_value ( op->values, op->num_values,
+					    op->params.trimmed_mean);
+      break;
+
     case OP_PSTDEV:
       numeric_result = stdev_value ( op->values, op->num_values, DF_POPULATION);
       break;
@@ -960,9 +970,9 @@ field_op_summarize (struct fieldop *op)
 
   if (op->res_type==NUMERIC_RESULT)
     {
-      field_op_reserve_out_buf (op, numeric_output_precision*2);
+      field_op_reserve_out_buf (op, numeric_output_bufsize);
       snprintf (op->out_buf, op->out_buf_alloc,
-                "%.*Lg", numeric_output_precision, numeric_result);
+                numeric_output_format, numeric_result);
     }
 }
 
