@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2017 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -15,7 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Datamash.  If not, see <http://www.gnu.org/licenses/>.
+   along with GNU Datamash.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 /* Written by Assaf Gordon */
@@ -75,7 +75,8 @@ enum field_operation
   OP_CEIL,          /* Ceiling */
   OP_ROUND,         /* Round */
   OP_TRUNCATE,      /* Truncate */
-  OP_FRACTION       /* Fraction */
+  OP_FRACTION,      /* Fraction */
+  OP_TRIMMED_MEAN   /* Trimmed Mean */
 };
 
 enum processing_mode
