@@ -82,7 +82,7 @@ line_record_init (struct line_record_t* lr);
 
 bool
 line_record_fread (struct /* in/out */ line_record_t* lr,
-                   FILE *stream, char delimiter);
+                   FILE *stream, char delimiter, bool skip_comments);
 
 void
 line_record_free (struct line_record_t* lr);
