@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2017 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -15,7 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Datamash.  If not, see <http://www.gnu.org/licenses/>.
+   along with GNU Datamash.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 /* Written by Assaf Gordon */
@@ -182,6 +182,13 @@ enum MODETYPE
 long double
 mode_value ( const long double * const values, size_t n, enum MODETYPE type);
 
+/*
+ Given an array of doubles, return the mode/anti-mode values.
+ */
+long double
+trimmed_mean_value ( const long double * const values, size_t n,
+		     const long double trimmed_mean_percent);
+
 
 /*
  comparison functions, to be used with 'qsort ()'
